import 'package:flutter/foundation.dart';
import 'package:flutter_flex_cart/src/payment.dart';

/// Payable
/// Add payment support to cart or settlements or invoice.
/// * [P] CorePayment
abstract class Payable<P extends CorePayment> with ChangeNotifier {
  final List<P> _payments;

  Payable({
    List<P>? payments,
  }) : _payments = payments ?? [];

  Iterable<P> get payments => List.unmodifiable(_payments);

  int get noOfPayments => _payments.length;

  double get totalPayments =>
      _payments.fold(0.0, (previousValue, curr) => curr.amount);

  /// Add payment to list overide this if you want any other logic when adding to the list
  /// Like if you want to add only one cash payment object summing up all the cash payments.
  void addPayment(P payment) {
    _payments.add(payment);
    notifyListeners();
  }

  void removePayment(int index) {
    _payments.removeAt(index);
    notifyListeners();
  }

  void reset() {
    _payments.clear();
    notifyListeners();
  }
}
